@@ -1,7 +1,9 @@
-examples_dir <- system.file( "examples", package = "retroharmonize")
+examples_dir <- system.file("examples", package = "retroharmonize")
 
-my_rds_files <- dir( examples_dir)[grepl(".rds", 
-                                         dir(examples_dir))]
+my_rds_files <- dir(examples_dir)[grepl(
+  ".rds",
+  dir(examples_dir)
+)]
 
 example_surveys <- read_surveys(file.path(examples_dir, my_rds_files))
 
